@@ -23,18 +23,14 @@ import meshio
 )
 def test(mesh):
     def writer(*args, **kwargs):
-        return meshio._abaqus.write(*args, **kwargs)
+        return meshio.abaqus.write(*args, **kwargs)
 
-    helpers.write_read(writer, meshio._abaqus.read, mesh, 1.0e-15)
-    return
+    helpers.write_read(writer, meshio.abaqus.read, mesh, 1.0e-15)
 
 
-@pytest.mark.parametrize(
-    "filename, ref_sum, ref_num_cells",
-    [("abaqus_mesh_ex.inp", -68501.914611293, 3492), ("UUea.inp", 4950.0, 50)],
-)
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
+@pytest.mark.parametrize("filename, ref_sum, ref_num_cells", [("UUea.inp", 4950.0, 50)])
+@pytest.mark.parametrize("binary", [False, True])
+def test_reference_file(filename, ref_sum, ref_num_cells, binary):
     this_dir = os.path.dirname(os.path.abspath(__file__))
     filename = os.path.join(this_dir, "meshes", "abaqus", filename)
     mesh = meshio.read(filename)
@@ -42,4 +38,3 @@ def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
     s = numpy.sum(mesh.points)
     assert abs(s - ref_sum) < tol * abs(ref_sum)
     assert len(mesh.cells["quad"]) == ref_num_cells
-    return
