@@ -22,11 +22,12 @@ def gmsh_periodic():
 @pytest.mark.parametrize(
     "mesh",
     [
+        helpers.line_mesh,
         helpers.tri_mesh,
         helpers.triangle6_mesh,
         helpers.quad_mesh,
         helpers.quad8_mesh,
-        helpers.tri_quad_mesh,
+        # helpers.tri_quad_mesh,
         helpers.tet_mesh,
         helpers.tet10_mesh,
         helpers.hex_mesh,
@@ -43,12 +44,10 @@ def gmsh_periodic():
         gmsh_periodic(),
     ],
 )
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_gmsh2(mesh, write_binary):
-    writer = partial(meshio._gmsh.write, fmt_version="2", write_binary=write_binary)
-
-    helpers.write_read(writer, meshio._gmsh.read, mesh, 1.0e-15)
-    return
+@pytest.mark.parametrize("binary", [False, True])
+def test_gmsh2(mesh, binary):
+    writer = partial(meshio.gmsh.write, fmt_version="2", binary=binary)
+    helpers.write_read(writer, meshio.gmsh.read, mesh, 1.0e-15)
 
 
 @pytest.mark.parametrize(
@@ -58,7 +57,7 @@ def test_gmsh2(mesh, write_binary):
         helpers.triangle6_mesh,
         helpers.quad_mesh,
         helpers.quad8_mesh,
-        helpers.tri_quad_mesh,
+        # helpers.tri_quad_mesh,
         helpers.tet_mesh,
         helpers.tet10_mesh,
         helpers.hex_mesh,
@@ -74,12 +73,11 @@ def test_gmsh2(mesh, write_binary):
         helpers.add_field_data(helpers.hex_mesh, [1, 3], int),
     ],
 )
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_gmsh40(mesh, write_binary):
-    writer = partial(meshio._gmsh.write, fmt_version="4.0", write_binary=write_binary)
+@pytest.mark.parametrize("binary", [False, True])
+def test_gmsh40(mesh, binary):
+    writer = partial(meshio.gmsh.write, fmt_version="4.0", binary=binary)
 
-    helpers.write_read(writer, meshio._gmsh.read, mesh, 1.0e-15)
-    return
+    helpers.write_read(writer, meshio.gmsh.read, mesh, 1.0e-15)
 
 
 @pytest.mark.parametrize(
@@ -89,7 +87,7 @@ def test_gmsh40(mesh, write_binary):
         helpers.triangle6_mesh,
         helpers.quad_mesh,
         helpers.quad8_mesh,
-        helpers.tri_quad_mesh,
+        # helpers.tri_quad_mesh,
         helpers.tet_mesh,
         helpers.tet10_mesh,
         helpers.hex_mesh,
@@ -106,27 +104,24 @@ def test_gmsh40(mesh, write_binary):
         gmsh_periodic(),
     ],
 )
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_gmsh41(mesh, write_binary):
-    writer = partial(meshio._gmsh.write, fmt_version="4.1", write_binary=write_binary)
-
-    helpers.write_read(writer, meshio._gmsh.read, mesh, 1.0e-15)
-    return
+@pytest.mark.parametrize("binary", [False, True])
+def test_gmsh41(mesh, binary):
+    writer = partial(meshio.gmsh.write, fmt_version="4.1", binary=binary)
+    helpers.write_read(writer, meshio.gmsh.read, mesh, 1.0e-15)
 
 
 def test_generic_io():
     helpers.generic_io("test.msh")
     # With additional, insignificant suffix:
     helpers.generic_io("test.0.msh")
-    return
 
 
 @pytest.mark.parametrize(
     "filename, ref_sum, ref_num_cells",
     [("insulated-2.2.msh", 2.001762136876221, {"line": 21, "triangle": 111})],
 )
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
+@pytest.mark.parametrize("binary", [False, True])
+def test_reference_file(filename, ref_sum, ref_num_cells, binary):
     this_dir = os.path.dirname(os.path.abspath(__file__))
     filename = os.path.join(this_dir, "meshes", "msh", filename)
     mesh = meshio.read(filename)
@@ -138,8 +133,8 @@ def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
         k: len(v["gmsh:physical"]) for k, v in mesh.cell_data.items()
     } == ref_num_cells
 
-    writer = partial(meshio._gmsh.write, fmt_version="2", write_binary=write_binary)
-    helpers.write_read(writer, meshio._gmsh.read, mesh, 1.0e-15)
+    writer = partial(meshio.gmsh.write, fmt_version="2", binary=binary)
+    helpers.write_read(writer, meshio.gmsh.read, mesh, 1.0e-15)
 
 
 @pytest.mark.parametrize(
