@@ -1,4 +1,5 @@
 import os
+import pathlib
 from functools import partial
 
 import numpy
@@ -8,6 +9,8 @@ import helpers
 import meshio
 
 test_set = [
+    helpers.line_mesh,
+    helpers.tri_mesh_2d,
     helpers.tri_mesh,
     helpers.triangle6_mesh,
     helpers.quad_mesh,
@@ -29,27 +32,25 @@ test_set = [
 
 
 @pytest.mark.parametrize("mesh", test_set)
-@pytest.mark.parametrize("write_binary", [True, False])
-def test(mesh, write_binary):
+@pytest.mark.parametrize("binary", [True, False])
+def test(mesh, binary):
     def writer(*args, **kwargs):
-        return meshio._vtk.write(*args, write_binary=write_binary, **kwargs)
+        return meshio.vtk.write(*args, binary=binary, **kwargs)
 
-    helpers.write_read(writer, meshio._vtk.read, mesh, 1.0e-15)
-    return
+    helpers.write_read(writer, meshio.vtk.read, mesh, 1.0e-15)
 
 
 def test_generic_io():
     helpers.generic_io("test.vtk")
     # With additional, insignificant suffix:
     helpers.generic_io("test.0.vtk")
-    return
 
 
 @pytest.mark.parametrize(
     "filename, ref_sum, ref_num_cells", [("rbc_001.vtk", 0.00031280518, 996)]
 )
-@pytest.mark.parametrize("write_binary", [False, True])
-def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
+@pytest.mark.parametrize("binary", [False, True])
+def test_reference_file(filename, ref_sum, ref_num_cells, binary):
     this_dir = os.path.dirname(os.path.abspath(__file__))
     filename = os.path.join(this_dir, "meshes", "vtk", filename)
 
@@ -58,9 +59,8 @@ def test_reference_file(filename, ref_sum, ref_num_cells, write_binary):
     s = numpy.sum(mesh.points)
     assert abs(s - ref_sum) < tol * ref_sum
     assert len(mesh.cells["triangle"]) == ref_num_cells
-    writer = partial(meshio._vtk.write, write_binary=write_binary)
-    helpers.write_read(writer, meshio._vtk.read, mesh, 1.0e-15)
-    return
+    writer = partial(meshio.vtk.write, binary=binary)
+    helpers.write_read(writer, meshio.vtk.read, mesh, 1.0e-15)
 
 
 @pytest.mark.parametrize(
@@ -85,5 +85,10 @@ def test_structured(filename, ref_cells, ref_num_cells, ref_num_pnt):
     assert len(mesh.points) == ref_num_pnt
 
 
+def test_pathlike():
+    this_dir = os.path.dirname(os.path.abspath(__file__))
+    meshio.read(pathlib.Path(this_dir, "meshes", "vtk", "rbc_001.vtk"))
+
+
 if __name__ == "__main__":
-    test(helpers.tri_mesh, write_binary=True)
+    test(helpers.tri_mesh, binary=True)
