@@ -6,6 +6,7 @@ import meshio
 lxml = pytest.importorskip("lxml")
 
 test_set = [
+    helpers.line_mesh,
     helpers.tri_mesh,
     helpers.triangle6_mesh,
     helpers.quad_mesh,
@@ -25,30 +26,28 @@ test_set = [
 
 
 @pytest.mark.parametrize("mesh", test_set)
-@pytest.mark.parametrize("write_binary", [False, True])
-def test(mesh, write_binary):
+@pytest.mark.parametrize("binary", [False, True])
+def test(mesh, binary):
     def writer(*args, **kwargs):
-        return meshio._vtu.write(
+        return meshio.vtu.write(
             *args,
-            write_binary=write_binary,
+            binary=binary,
             # don't use pretty xml to increase test coverage
-            pretty_xml=False,
+            # pretty_xml=False,
             **kwargs,
         )
 
     # ASCII files are only meant for debugging, VTK stores only 11 digits
     # <https://gitlab.kitware.com/vtk/vtk/issues/17038#note_264052>
-    tol = 1.0e-15 if write_binary else 1.0e-11
-    helpers.write_read(writer, meshio._vtu.read, mesh, tol)
-    return
+    tol = 1.0e-15 if binary else 1.0e-10
+    helpers.write_read(writer, meshio.vtu.read, mesh, tol)
 
 
 def test_generic_io():
     helpers.generic_io("test.vtu")
     # With additional, insignificant suffix:
     helpers.generic_io("test.0.vtu")
-    return
 
 
 if __name__ == "__main__":
-    test(helpers.tet10_mesh, write_binary=False)
+    test(helpers.tet10_mesh, binary=False)
